@@ -97,8 +97,7 @@ class AppSetup(Controller):
             backend_image_tag = f'{plugin_name}-backend:latest'
             print(backend_image_tag)
             print(self.container_registry)
-            os.system(f'cd {self.backend_path}')
-            os.system(f'docker build -t {backend_image_tag} .')
+            os.system(f'cd {self.backend_path} && docker build -t {backend_image_tag} .')
             os.system(f'docker tag {backend_image_tag} {self.container_registry}/{backend_image_tag}')
             os.system(f'docker push {self.container_registry}/{backend_image_tag}')
         except OSError as e:
